@@ -3,27 +3,21 @@
 # test/scaffold.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2007–2015 Ben Finney <ben+python@benfinney.id.au>
-#
-# This is free software: you may copy, modify, and/or distribute this work
-# under the terms of the Apache License, version 2.0 as published by the
-# Apache Software Foundation.
-# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
+# This is free software, and you are welcome to redistribute it under
+# certain conditions; see the end of this file for copyright
+# information, grant of license, and disclaimer of warranty.
 
 """ Scaffolding for unit test modules.
     """
 
 from __future__ import (absolute_import, unicode_literals)
 
-import unittest
+from copy import deepcopy
 import doctest
+import functools
 import logging
-import os
-import sys
 import operator
 import textwrap
-from copy import deepcopy
-import functools
 
 try:
     # Python 2 has both ‘str’ (bytes) and ‘unicode’ (text).
@@ -101,7 +95,7 @@ def format_function_signature(func):
         :param func: The function object to interrogate.
         :return: A formatted text representation of the function signature.
 
-        The signature is rendered a text; for example::
+        The signature is rendered as text; for example::
 
             foo(spam, eggs, ham=True, beans=None, *args, **kwargs)
 
@@ -246,8 +240,8 @@ class TestCase(testtools.testcase.TestCase):
                         Expected:
                             {first_text}
                         Got:
-                            {second_text}""")
-                        ).format(
+                            {second_text}
+                        """)).format(
                             first=first_signature,
                             first_text=first_signature_text,
                             second=second_signature,
@@ -307,6 +301,14 @@ def make_exception_scenarios(scenarios):
 
     return updated_scenarios
 
+
+# Copyright © 2007–2018 Ben Finney <ben+python@benfinney.id.au>
+#
+# This is free software: you may copy, modify, and/or distribute this work
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; version 3 of that license or any later version.
+# No warranty expressed or implied. See the file ‘LICENSE.GPL-3’ for details.
+
 
 # Local variables:
 # coding: utf-8
