@@ -3,19 +3,19 @@
 # test/test_metadata.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2008–2016 Ben Finney <ben+python@benfinney.id.au>
-#
-# This is free software: you may copy, modify, and/or distribute this work
-# under the terms of the Apache License, version 2.0 as published by the
-# Apache Software Foundation.
-# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
+# This is free software, and you are welcome to redistribute it under
+# certain conditions; see the end of this file for copyright
+# information, grant of license, and disclaimer of warranty.
 
 """ Unit test for ‘_metadata’ private module.
     """
 
 from __future__ import (absolute_import, unicode_literals)
 
+import collections
 import errno
+import functools
+import json
 import re
 try:
     # Python 3 standard library.
@@ -23,12 +23,9 @@ try:
 except ImportError:
     # Python 2 standard library.
     import urlparse
-import functools
-import collections
-import json
 
-import pkg_resources
 import mock
+import pkg_resources
 import testtools.helpers
 import testtools.matchers
 
@@ -185,8 +182,8 @@ class metadata_content_TestCase(scaffold.TestCase):
         """ Copyright statement should be formatted correctly. """
         regex_pattern = (
                 "Copyright © "
-                "\d{4}" # four-digit year
-                "(?:–\d{4})?" # optional range dash and ending four-digit year
+                "\d{4}"  # Four-digit year.
+                "(?:–\d{4})?"  # Optional range dash and four-digit year.
                 )
         regex_flags = re.UNICODE
         self.assertThat(
@@ -196,8 +193,8 @@ class metadata_content_TestCase(scaffold.TestCase):
     def test_author_formatted_correctly(self):
         """ Author information should be formatted correctly. """
         regex_pattern = (
-                ".+ " # name
-                "<[^>]+>" # email address, in angle brackets
+                ".+ "  # Name.
+                "<[^>]+>"  # Email address, in angle brackets.
                 )
         regex_flags = re.UNICODE
         self.assertThat(
@@ -333,7 +330,7 @@ class get_distribution_version_info_TestCase(scaffold.TestCaseWithScenarios):
     def test_requests_installed_distribution(self):
         """ The package distribution should be retrieved. """
         expected_distribution_name = metadata.distribution_name
-        version_info = metadata.get_distribution_version_info(**self.test_args)
+        metadata.get_distribution_version_info(**self.test_args)
         pkg_resources.get_distribution.assert_called_with(
                 expected_distribution_name)
 
@@ -341,7 +338,7 @@ class get_distribution_version_info_TestCase(scaffold.TestCaseWithScenarios):
         """ The specified metadata resource name should be requested. """
         if hasattr(self, 'get_distribution_error'):
             self.skipTest("No access to distribution")
-        version_info = metadata.get_distribution_version_info(**self.test_args)
+        metadata.get_distribution_version_info(**self.test_args)
         self.mock_distribution.has_metadata.assert_called_with(
                 self.expected_resource_name)
 
@@ -350,6 +347,14 @@ class get_distribution_version_info_TestCase(scaffold.TestCaseWithScenarios):
         version_info = metadata.get_distribution_version_info(**self.test_args)
         self.assertEqual(self.expected_version_info, version_info)
 
+
+# Copyright © 2008–2018 Ben Finney <ben+python@benfinney.id.au>
+#
+# This is free software: you may copy, modify, and/or distribute this work
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; version 3 of that license or any later version.
+# No warranty expressed or implied. See the file ‘LICENSE.GPL-3’ for details.
+
 
 # Local variables:
 # coding: utf-8
