@@ -3,12 +3,9 @@
 # test/test_pidfile.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2008–2016 Ben Finney <ben+python@benfinney.id.au>
-#
-# This is free software: you may copy, modify, and/or distribute this work
-# under the terms of the Apache License, version 2.0 as published by the
-# Apache Software Foundation.
-# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
+# This is free software, and you are welcome to redistribute it under
+# certain conditions; see the end of this file for copyright
+# information, grant of license, and disclaimer of warranty.
 
 """ Unit test for ‘pidfile’ module.
     """
@@ -21,15 +18,15 @@ try:
 except ImportError:
     # Python 2 standard library.
     import __builtin__ as builtins
-import os
-import itertools
-import tempfile
-import io
 import errno
 import functools
+import io
+import itertools
+import os
+import tempfile
 
-import mock
 import lockfile
+import mock
 
 from . import scaffold
 
@@ -273,8 +270,6 @@ def setup_pidfile_fixtures(testcase):
     testcase.addCleanup(func_patcher_os_open.stop)
 
     def fake_os_fdopen(fd, mode='rt', buffering=None):
-        scenario_pidfile = get_scenario_option(
-                testcase, 'pidfile', FakeFileDescriptorStringIO())
         if fd == testcase.scenario['pidfile'].fileno():
             result = testcase.scenario['pidfile']
         else:
@@ -389,7 +384,6 @@ class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
 
         pidlockfile_scenarios = make_pidlockfile_scenarios()
         self.pidlockfile_scenario = pidlockfile_scenarios['simple']
-        pidfile_path = self.pidlockfile_scenario['pidfile_path']
 
         for func_name in ['__init__', 'acquire']:
             func_patcher = mock.patch.object(
@@ -452,13 +446,23 @@ class TimeoutPIDLockFile_TestCase(scaffold.TestCase):
             lockfile.pidlockfile.PIDLockFile, "acquire",
             autospec=True)
     def test_acquire_uses_stored_timeout_by_default(self, mock_func_acquire):
-        """ Should call superclass ‘acquire’ with stored timeout by default. """
+        """
+        Should call superclass ‘acquire’ with stored timeout by default.
+        """
         instance = self.test_instance
         test_timeout = self.test_kwargs['acquire_timeout']
         expected_timeout = test_timeout
         instance.acquire()
         mock_func_acquire.assert_called_with(instance, expected_timeout)
 
+
+# Copyright © 2008–2018 Ben Finney <ben+python@benfinney.id.au>
+#
+# This is free software: you may copy, modify, and/or distribute this work
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; version 3 of that license or any later version.
+# No warranty expressed or implied. See the file ‘LICENSE.GPL-3’ for details.
+
 
 # Local variables:
 # coding: utf-8
