@@ -3,12 +3,9 @@
 # test/test_runner.py
 # Part of ‘python-daemon’, an implementation of PEP 3143.
 #
-# Copyright © 2009–2015 Ben Finney <ben+python@benfinney.id.au>
-#
-# This is free software: you may copy, modify, and/or distribute this work
-# under the terms of the Apache License, version 2.0 as published by the
-# Apache Software Foundation.
-# No warranty expressed or implied. See the file ‘LICENSE.ASF-2’ for details.
+# This is free software, and you are welcome to redistribute it under
+# certain conditions; see the end of this file for copyright
+# information, grant of license, and disclaimer of warranty.
 
 """ Unit test for ‘runner’ module.
     """
@@ -21,59 +18,57 @@ try:
 except ImportError:
     # Python 2 standard library.
     import __builtin__ as builtins
+import errno
+import functools
 import os
 import os.path
-import sys
-import tempfile
-import errno
 import signal
-import functools
+import sys
 
 import lockfile
 import mock
-import testtools
 
 from . import scaffold
-from .scaffold import (basestring, unicode)
-from .test_pidfile import (
-        FakeFileDescriptorStringIO,
-        setup_pidfile_fixtures,
-        make_pidlockfile_scenarios,
-        apply_lockfile_method_mocks,
-        )
+from .scaffold import unicode
 from .test_daemon import (
         setup_streams_fixtures,
         )
+from .test_pidfile import (
+        FakeFileDescriptorStringIO,
+        apply_lockfile_method_mocks,
+        make_pidlockfile_scenarios,
+        setup_pidfile_fixtures,
+        )
 
 import daemon.daemon
-import daemon.runner
 import daemon.pidfile
+import daemon.runner
 
 
 class ModuleExceptions_TestCase(scaffold.Exception_TestCase):
     """ Test cases for module exception classes. """
 
     scenarios = scaffold.make_exception_scenarios([
-            ('daemon.runner.DaemonRunnerError', dict(
-                exc_type = daemon.runner.DaemonRunnerError,
-                min_args = 1,
-                types = [Exception],
-                )),
-            ('daemon.runner.DaemonRunnerInvalidActionError', dict(
-                exc_type = daemon.runner.DaemonRunnerInvalidActionError,
-                min_args = 1,
-                types = [daemon.runner.DaemonRunnerError, ValueError],
-                )),
-            ('daemon.runner.DaemonRunnerStartFailureError', dict(
-                exc_type = daemon.runner.DaemonRunnerStartFailureError,
-                min_args = 1,
-                types = [daemon.runner.DaemonRunnerError, RuntimeError],
-                )),
-            ('daemon.runner.DaemonRunnerStopFailureError', dict(
-                exc_type = daemon.runner.DaemonRunnerStopFailureError,
-                min_args = 1,
-                types = [daemon.runner.DaemonRunnerError, RuntimeError],
-                )),
+            ('daemon.runner.DaemonRunnerError', {
+                'exc_type': daemon.runner.DaemonRunnerError,
+                'min_args': 1,
+                'types': [Exception],
+                }),
+            ('daemon.runner.DaemonRunnerInvalidActionError', {
+                'exc_type': daemon.runner.DaemonRunnerInvalidActionError,
+                'min_args': 1,
+                'types': [daemon.runner.DaemonRunnerError, ValueError],
+                }),
+            ('daemon.runner.DaemonRunnerStartFailureError', {
+                'exc_type': daemon.runner.DaemonRunnerStartFailureError,
+                'min_args': 1,
+                'types': [daemon.runner.DaemonRunnerError, RuntimeError],
+                }),
+            ('daemon.runner.DaemonRunnerStopFailureError', {
+                'exc_type': daemon.runner.DaemonRunnerStopFailureError,
+                'min_args': 1,
+                'types': [daemon.runner.DaemonRunnerError, RuntimeError],
+                }),
             ])
 
 
@@ -314,7 +309,6 @@ class DaemonRunner_TestCase(DaemonRunner_BaseTestCase):
 
     def test_daemon_context_has_specified_stdin_stream(self):
         """ DaemonContext component should have specified stdin file. """
-        test_app = self.test_app
         expected_file = self.stream_files_by_name['stdin']
         daemon_context = self.test_instance.daemon_context
         self.assertEqual(expected_file, daemon_context.stdin)
@@ -327,7 +321,6 @@ class DaemonRunner_TestCase(DaemonRunner_BaseTestCase):
 
     def test_daemon_context_has_specified_stdout_stream(self):
         """ DaemonContext component should have specified stdout file. """
-        test_app = self.test_app
         expected_file = self.stream_files_by_name['stdout']
         daemon_context = self.test_instance.daemon_context
         self.assertEqual(expected_file, daemon_context.stdout)
@@ -340,7 +333,6 @@ class DaemonRunner_TestCase(DaemonRunner_BaseTestCase):
 
     def test_daemon_context_has_specified_stderr_stream(self):
         """ DaemonContext component should have specified stderr file. """
-        test_app = self.test_app
         expected_file = self.stream_files_by_name['stderr']
         daemon_context = self.test_instance.daemon_context
         self.assertEqual(expected_file, daemon_context.stderr)
@@ -402,7 +394,7 @@ class DaemonRunner_parse_args_TestCase(DaemonRunner_BaseTestCase):
         """ Should emit a usage message and exit if too few arguments. """
         instance = self.test_instance
         argv = [self.test_program_path]
-        exc = self.assertRaises(
+        self.assertRaises(
                 NotImplementedError,
                 instance.parse_args, argv)
         daemon.runner.DaemonRunner._usage_exit.assert_called_with(argv)
@@ -410,9 +402,8 @@ class DaemonRunner_parse_args_TestCase(DaemonRunner_BaseTestCase):
     def test_emits_usage_message_if_unknown_action_arg(self):
         """ Should emit a usage message and exit if unknown action. """
         instance = self.test_instance
-        progname = self.test_program_name
         argv = [self.test_program_path, 'bogus']
-        exc = self.assertRaises(
+        self.assertRaises(
                 NotImplementedError,
                 instance.parse_args, argv)
         daemon.runner.DaemonRunner._usage_exit.assert_called_with(argv)
@@ -477,12 +468,11 @@ class DaemonRunner_do_action_start_TestCase(DaemonRunner_BaseTestCase):
         self.assertIn(expected_message_content, unicode(exc))
 
     def test_breaks_lock_if_no_such_process(self):
-        """ Should request breaking lock if PID file process is not running. """
+        """ Should request breaking lock if PID file process not running. """
         set_runner_scenario(self, 'pidfile-locked')
         instance = self.test_instance
         self.mock_runner_lockfile.read_pid.return_value = (
                 self.scenario['pidlockfile_scenario']['pidfile_pid'])
-        pidfile_path = self.scenario['pidfile_path']
         test_pid = self.scenario['pidlockfile_scenario']['pidfile_pid']
         expected_signal = signal.SIG_DFL
         test_error = ProcessLookupError("Not running")
@@ -550,9 +540,6 @@ class DaemonRunner_do_action_stop_TestCase(DaemonRunner_BaseTestCase):
     def test_breaks_lock_if_pidfile_stale(self):
         """ Should break lock if PID file is stale. """
         instance = self.test_instance
-        pidfile_path = self.scenario['pidfile_path']
-        test_pid = self.scenario['pidlockfile_scenario']['pidfile_pid']
-        expected_signal = signal.SIG_DFL
         test_error = OSError(errno.ESRCH, "Not running")
         os.kill.side_effect = test_error
         instance.do_action()
@@ -570,7 +557,6 @@ class DaemonRunner_do_action_stop_TestCase(DaemonRunner_BaseTestCase):
         """ Should raise error if cannot send signal to daemon process. """
         instance = self.test_instance
         test_pid = self.scenario['pidlockfile_scenario']['pidfile_pid']
-        pidfile_path = self.scenario['pidfile_path']
         test_error = OSError(errno.EPERM, "Nice try")
         os.kill.side_effect = test_error
         expected_error = daemon.runner.DaemonRunnerStopFailureError
@@ -667,6 +653,14 @@ class is_pidfile_stale_TestCase(scaffold.TestCase):
         result = daemon.runner.is_pidfile_stale(self.test_pidfile)
         self.assertEqual(expected_result, result)
 
+
+# Copyright © 2009–2018 Ben Finney <ben+python@benfinney.id.au>
+#
+# This is free software: you may copy, modify, and/or distribute this work
+# under the terms of the GNU General Public License as published by the
+# Free Software Foundation; version 3 of that license or any later version.
+# No warranty expressed or implied. See the file ‘LICENSE.GPL-3’ for details.
+
 
 # Local variables:
 # coding: utf-8
